@@ -1,4 +1,7 @@
-sdellipse = function (points, stdev = 1.96, density = .1, output = FALSE, add = TRUE, show = TRUE, means = NULL, ...){
+# Copyright (c) 2013 Santiago Barreda
+# All rights reserved.
+
+sdellipse = function (points, stdev = 1.96, density = .1, add = TRUE, show = TRUE, means = NULL, ...){
   if (ncol (points) != 2) stop ('Points input must have exactly two columns.')
   if (!is.null(means) & nrow(points) > 2) stop ('Covariance matrix must be 2 by 2.')
   if (!is.null(means) & length(means) > 2) stop ('Exactly two means must be specified.')
@@ -15,8 +18,6 @@ sdellipse = function (points, stdev = 1.96, density = .1, output = FALSE, add =
   
   if (add == TRUE & show == TRUE) lines (points, ...)
   if (add == FALSE & show == TRUE) plot (points, type = 'l', ...)
-  if (output == TRUE) return (points)
+  invisible (points)
 }
 
-
-
